@@ -25,7 +25,6 @@ class Timeout(ITimeout):
     def start(self) -> None:
         self._st = self._current()
 
-    @property
     def is_timeout(self) -> bool:
         return self._is_timeout()
 
@@ -36,4 +35,4 @@ class Timeout(ITimeout):
         return self._timestamp.convert(self._current() - self._st) >= self._timeout
 
     def __str__(self):
-        return f"{self.__class__.__name__}(timeout={self._timeout})"
+        return f"{self.__class__.__name__}(timeout={self._timeout}, st={self._st})"
