@@ -3,5 +3,5 @@
 # @IDE      : PyCharm
 # @Author   : Angel
 # @Email    : 376355670@qq.com
-from .base import IWorkerJoin
+from .base import IJoin
 from .worker_join import WorkerJoin
