@@ -5,8 +5,8 @@
 # @Email    : 376355670@qq.com
 from .base import IWorker, IWorkerMaster, IWorkerFactory
 from .handler import IWorkerHandler, WorkerHandler
-from .worker import IWorker, CounterWorker, TimeoutWorker, WorkerGroup, is_worker
+from .worker import IWorker, CounterWorker, TimeoutWorker, WorkerGroup
 from .master import WorkerMaster
 from .builder import AbstractWorkerBuilder, CounterWorkerBuilder, TimeoutWorkerBuilder
-from .factory import WorkerGroupFactory, WorkerMasterFactory, create_group, create_master, run
+from .factory import WorkerGroupFactory, WorkerMasterFactory
 from .decorate import AbstractWorkerDecorate, CounterWorkerDecorate, TimeoutWorkerDecorate
