@@ -11,7 +11,7 @@ from f1z1_async_runner.src import create_runner, start
 from ..components.gather import IGather
 from ..components.record import IRecorder
 from .base import IWorkerMaster
-from .worker import IWorker, is_worker
+from .worker import IWorker
 
 
 class WorkerMaster(IWorkerMaster):
@@ -60,7 +60,7 @@ class WorkerMaster(IWorkerMaster):
         return min(gather.length(), cpu_count())
 
     def _check_worker(self, worker):
-        if not is_worker(worker):
+        if not isinstance(worker, IWorker):
             raise ValueError(
                 f"worker need IWorker or IWorkerGroup, but got {type(worker).__name__}"
             )
